pub struct MidScaleInt { /* private fields */ }Expand description
Mid-scale integers (中数).
「中数者,万万变之。若言万万曰亿,万万亿曰兆,万万兆曰京也。」
Implementations
Sourceimpl MidScaleInt
impl MidScaleInt
Sourcepub fn new_non_pos(abs: u128) -> Self
pub fn new_non_pos(abs: u128) -> Self
Generates a new non-positive mid-scale integer from given absolute value.
There is no way to generate Chinese numerals by From trait from negative primitive numbers less than i128::MIN. This associated function provides a way to generate them from the given absolute value less than or equal to u128::MAX. This crate also provides struct MidScaleBigInt for integers with absolute value larger than u128::MAX.